/*
 * Name: Image Resizer
 * Developer: Vinyl
 * Date: 12/18/2015
 */
define(function () {

    var rotate = function (cell, degree) {
        var cellData = cell.value;
        if (!cellData.startsWith("http")) {
            cellData = 'data:image/png;base64,' + cellData;
        }

        var can = document.createElement("canvas");
        var ctx = can.getContext('2d');

        var image = new Image();
        image.onload = function() {
            can.width = image.width;
            can.height = image.height;

            ctx.translate(can.width / 2, can.height / 2);
            ctx.rotate(degree * Math.PI / 180);
            ctx.drawImage(image, -image.width / 2, -image.width / 2);

            var dataUrl = can.toDataURL();
            var result = dataUrl.slice(dataUrl.indexOf(',') + 1);
            cell.value = result;
        }
        image.src = cellData;
    };

    var install = function (holderElement, context) {
        var cell = context.getCell();

        // hide the control if not in edit state
        var displayValue = context.isEditState() ? "" : "none";
        holderElement.parentNode.style.display = displayValue;

        var left = holderElement.children[0];
        var right = holderElement.children[1];

        var row = context.getRow();

        left.addEventListener('click', function () {
            rotate(cell, 90);
        }, false);

        right.addEventListener('click', function () {
            rotate(cell, -90);
        }, false);
    };

    var uninstall = function(holderElement, context) {
    };

    return {
        callbacks: {
            events: {
                // adding and removing
                install: install,
                uninstall: uninstall
            }
        }
    };
});
